==> AGXUnreal-1.17.0_UE-5.6_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Vehicles/Tracks/ContactGeometryLinkDescription.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Vehicles/VehiclesForward.h>
#include <openplx/DriveTrain/DriveTrainForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics1D/Physics1DForward.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Vehicles/Tracks/DefaultLinkDescription.h>
#include <openplx/Physics3D/Charges/ContactGeometry.h>
/* Generated code for model ContactGeometryLinkDescription */
namespace openplx::Vehicles::Tracks {
    /**
     * Defines links with a contact_geometry for the belt of a track system.
     **/
    class ContactGeometryLinkDescription : public openplx::Vehicles::Tracks::DefaultLinkDescription {
        protected:
            std::shared_ptr<openplx::Physics3D::Charges::ContactGeometry> m_contact_geometry;

        public:
            ContactGeometryLinkDescription();
            std::shared_ptr<openplx::Physics3D::Charges::ContactGeometry> contact_geometry() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.0.0_UE-5.5_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Vehicles/Tracks/ContactGeometryLinkDescription.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Vehicles/VehiclesBundleExport.h>
#include <openplx/Vehicles/VehiclesForward.h>
#include <openplx/DriveTrain/DriveTrainForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics1D/Physics1DForward.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Vehicles/Tracks/DefaultLinkDescription.h>
#include <openplx/Physics3D/Geometries/ContactGeometry.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model ContactGeometryLinkDescription */
namespace openplx::Vehicles::Tracks {
    /**
     * Defines links with a contact_geometry for the belt of a track system.
     **/
    class OPENPLX_Vehicles_BUNDLE_EXPORT ContactGeometryLinkDescription : public openplx::Vehicles::Tracks::DefaultLinkDescription {
        protected:
            std::shared_ptr<openplx::Physics3D::Geometries::ContactGeometry> m_contact_geometry;

        public:
            ContactGeometryLinkDescription();
            virtual ~ContactGeometryLinkDescription();
            std::shared_ptr<openplx::Physics3D::Geometries::ContactGeometry> contact_geometry() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
